@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+
 
 #
 # testValidate
@@ -18,8 +18,8 @@
 
 use strict;
 
-BEGIN { unshift @INC,'/home/liu/PerlCDF36_4/blib/arch',
-                     '/home/liu/PerlCDF36_4/blib/lib'; }
+BEGIN { unshift @INC,'/home/liu/PerlCDF38_0/blib/arch',
+                     '/home/liu/PerlCDF38_0/blib/lib'; }
 use CDF;
 
 my $file = $ARGV[0];
@@ -29,21 +29,21 @@ my $file = $ARGV[0];
 #############################################################################
 
 print "\nTesting Perl-CDF Data Validation\n\n";
-CDF::CDFsetValidate(VALIDATEFILEon);
-# CDF::CDFsetValidate(VALIDATEFILEoff);
+CDF::CDFsetValidate(&VALIDATEFILEon);
+# CDF::CDFsetValidate(&VALIDATEFILEoff);
 
 my $id; my $status;
-$status = CDF::CDFlib(OPEN_, CDF_, $file, \$id,
- 		      NULL_);
-QuitCDF ("1.0", $status) if ($status < CDF_OK); 
+$status = CDF::CDFlib(&OPEN_, &CDF_, $file, \$id,
+ 		      &NULL_);
+QuitCDF ("1.0", $status) if ($status < &CDF_OK); 
 
 #############################################################################
 # Close CDF.
 #############################################################################
 
-$status = CDF::CDFlib (CLOSE_, CDF_,
-		       NULL_);
-QuitCDF ("2.0", $status) if ($status < CDF_OK) ;
+$status = CDF::CDFlib (&CLOSE_, &CDF_,
+		       &NULL_);
+QuitCDF ("2.0", $status) if ($status < &CDF_OK) ;
 
 #############################################################################
 # Successful completion.
@@ -58,15 +58,15 @@ sub QuitCDF {
 	my ($where, $status)=@_;
 
   print "Aborting at $where ...\n";
-  if ($status < CDF_OK) {
+  if ($status < &CDF_OK) {
     my $text;
-    CDF::CDFlib (SELECT_, CDF_STATUS_, $status,
-		   GET_, STATUS_TEXT_, \$text,
-		   NULL_);
+    CDF::CDFlib (&SELECT_, &CDF_STATUS_, $status,
+		   &GET_, &STATUS_TEXT_, \$text,
+		   &NULL_);
     print $text;
   }
-  CDF::CDFlib (CLOSE_, CDF_,
-	  NULL_);
+  CDF::CDFlib (&CLOSE_, &CDF_,
+	  &NULL_);
   print "...test aborted.\n";
   exit;
 	
